@@ -1258,7 +1258,7 @@ void *OpenPri::RunDchannelLog(void *p)
 	pri_event *e;
 	struct timeval ts;
 	fd_set rfds, efds;
-	int res, i, x = 0;
+	int res, x = 0;
 	struct pri *pri;
 	struct pri *pri2;
 	struct pri *pritmp = NULL;
@@ -1272,7 +1272,6 @@ void *OpenPri::RunDchannelLog(void *p)
 
 	VPBREG *v      = &openpri->m_reg;
 	int cardnum    = v->cardnum;
-	int numch      = v->numch;
 
 	OP_CARD *cardinfo = (OP_CARD *)v->cardinfo;
 	pri_chan *chans   = (pri_chan *)v->chans;
@@ -1281,33 +1280,31 @@ void *OpenPri::RunDchannelLog(void *p)
 	int swtype = cardinfo->protocol;
 	int node   = PRI_CPE;
 
-	// Split up channel and card names
-	// iface is initialised from config file which uses channel1 - channel31
-	// when numch = 30.
-	// NOTE: bad things will happen here if any (active) channel is not listed
-	//       in the config file.  FIXME
-	for(i=1; i < numch + 2; ++i){
-		tmpstr = strchr((char *)cardinfo->iface[i].name,',');
-		if (tmpstr != NULL){
-			*tmpstr = '\0';
-			tmpstr++;
-			strcpy((char *)cardinfo->iface[i].name2,tmpstr);
-		}
-		tmpstr = strchr((char *)cardinfo->iface[i].card,',');
-		if (tmpstr != NULL){
-			*tmpstr = '\0';
-			tmpstr++;
-			strcpy((char *)cardinfo->iface[i].card2,tmpstr);
-		}
-	}
 	// Get D-channel from config file
 	int d_chan = cardinfo->d_channel;
 
+	// Split up channel and card names
+	// iface is initialised from config file which uses channel1 - channel31
+	// when numch = 30.
+	char card2[32];
+	char name2[32];
+
+	tmpstr = strchr((char*)cardinfo->iface[d_chan].name, ',');
+	if (tmpstr != NULL) {
+		*tmpstr++ = '\0';
+		strcpy(name2, tmpstr);
+	}
+	tmpstr = strchr((char*)cardinfo->iface[d_chan].card, ',');
+	if (tmpstr != NULL) {
+		*tmpstr++ = '\0';
+		strcpy(card2, tmpstr);
+	}
+
 	int dfd = wanconnect((char*)cardinfo->iface[d_chan].card,
 			     (char*)cardinfo->iface[d_chan].name);
-	int dfd2 = wanconnect((char*)cardinfo->iface[d_chan].card2,
-			      (char*)cardinfo->iface[d_chan].name2);
-	if( dfd < 0 || dfd2 < 0 ){
+	int dfd2 = wanconnect(card2, name2);
+
+	if( dfd < 0 || dfd2 < 0 ) {
 		mprintf("[%d/-] Failed[%d] to open dchannel '%s'\n",
 			cardnum, dfd, cardinfo->iface[d_chan].name);
 		pthread_exit( NULL );
@@ -1315,7 +1312,7 @@ void *OpenPri::RunDchannelLog(void *p)
 		mprintf("[%d/-] Opened 1/2 D-Channel on fd[%d] using '%s'\n",
 			cardnum,dfd,cardinfo->iface[d_chan].name);
 		mprintf("[%d/-] Opened 1/2 D-Channel on fd[%d] using '%s'\n",
-			cardnum,dfd2,cardinfo->iface[d_chan].name2);
+			cardnum, dfd2, name2);
 	}
 	mprintf("[%d/-] D-Channel is in logging mode!\n",cardnum);
 
@@ -2286,17 +2283,15 @@ static void *audio_thread_log_multi(void *pv)
 	unsigned char buf2[16 + (channels * NBUF)];
 
 	// Split up channel and card names
-	tmpstr = strchr((char *)info->interface,',');
-	if (tmpstr != NULL){
-		*tmpstr = '\0';
-		++tmpstr;
-		strcpy(interface2,tmpstr);
+	tmpstr = strchr((char*)info->interface, ',');
+	if (tmpstr != NULL) {
+		*tmpstr++ = '\0';
+		strcpy(interface2, tmpstr);
 	}
-	tmpstr = strchr((char *)info->card,',');
-	if (tmpstr != NULL){
-		*tmpstr = '\0';
-		++tmpstr;
-		strcpy(card2,tmpstr);
+	tmpstr = strchr((char*)info->card, ',');
+	if (tmpstr != NULL) {
+		*tmpstr++ = '\0';
+		strcpy(card2, tmpstr);
 	}
 
 	for(i=0; i < 256; ++i) {
@@ -2316,14 +2311,15 @@ static void *audio_thread_log_multi(void *pv)
 		info->card, info->interface);
 
 	for(;;) {
-	    c_fd = wanconnect((char *)info->card,(char *)info->interface);
-	    c_fd2 = wanconnect(card2,interface2);
+	    c_fd = wanconnect((char*)info->card, (char*)info->interface);
 	    if (c_fd < 0) {
 		mprintf("Failed to connect to channel interface on card '%s' iface '%s': %d\n",
 			info->card,info->interface, c_fd);
 		pthread_exit(NULL);
 	    }
-	    else if (c_fd2 < 0) {
+
+	    c_fd2 = wanconnect(card2, interface2);
+	    if (c_fd2 < 0) {
 		mprintf("Failed to connect to channel interface on card '%s' iface '%s': %d\n",
 			card2, interface2, c_fd2);
 		pthread_exit(NULL);
